@@ -25,9 +25,15 @@ import (
 	"testing"
 	"time"
 
-	mock "k8s.io/apiserver/pkg/storage/value/encrypt/envelope/testing/v2alpha1"
-
 	"k8s.io/apimachinery/pkg/util/uuid"
+	"k8s.io/apiserver/pkg/storage/value/encrypt/envelope/metrics"
+	mock "k8s.io/apiserver/pkg/storage/value/encrypt/envelope/testing/v2"
+	"k8s.io/component-base/metrics/testutil"
+	kmsservice "k8s.io/kms/pkg/service"
+)
+
+const (
+	testProviderName = "providerName"
 )
 
 type testSocket struct {
@@ -56,7 +62,7 @@ func TestKMSPluginLateStart(t *testing.T) {
 
 	ctx := testContext(t)
 
-	service, err := NewGRPCService(ctx, s.endpoint, callTimeout)
+	service, err := NewGRPCService(ctx, s.endpoint, testProviderName, callTimeout)
 	if err != nil {
 		t.Fatalf("failed to create envelope service, error: %v", err)
 	}
@@ -120,7 +126,7 @@ func TestTimeouts(t *testing.T) {
 		t.Run(tt.desc, func(t *testing.T) {
 			t.Parallel()
 			var (
-				service         Service
+				service         kmsservice.Service
 				err             error
 				data            = []byte("test data")
 				uid             = string(uuid.NewUUID())
@@ -140,9 +146,10 @@ func TestTimeouts(t *testing.T) {
 				// Simulating late start of kube-apiserver - plugin is up before kube-apiserver, if requested by the testcase.
 				time.Sleep(tt.kubeAPIServerDelay)
 
-				service, err = NewGRPCService(ctx, socketName.endpoint, tt.callTimeout)
+				service, err = NewGRPCService(ctx, socketName.endpoint, testProviderName, tt.callTimeout)
 				if err != nil {
-					t.Fatalf("failed to create envelope service, error: %v", err)
+					t.Errorf("failed to create envelope service, error: %v", err)
+					return
 				}
 				defer destroyService(service)
 				kubeAPIServerWG.Done()
@@ -157,10 +164,12 @@ func TestTimeouts(t *testing.T) {
 
 				f, err := mock.NewBase64Plugin(socketName.path)
 				if err != nil {
-					t.Fatalf("failed to construct test KMS provider server, error: %v", err)
+					t.Errorf("failed to construct test KMS provider server, error: %v", err)
+					return
 				}
 				if err := f.Start(); err != nil {
-					t.Fatalf("Failed to start test KMS provider server, error: %v", err)
+					t.Errorf("Failed to start test KMS provider server, error: %v", err)
+					return
 				}
 				defer f.CleanUp()
 				kmsPluginWG.Done()
@@ -169,6 +178,9 @@ func TestTimeouts(t *testing.T) {
 			}()
 
 			kubeAPIServerWG.Wait()
+			if t.Failed() {
+				return
+			}
 			_, err = service.Encrypt(ctx, uid, data)
 
 			if err == nil && tt.wantErr != "" {
@@ -210,7 +222,7 @@ func TestIntermittentConnectionLoss(t *testing.T) {
 	ctx := testContext(t)
 
 	//  connect to kms plugin
-	service, err := NewGRPCService(ctx, endpoint.endpoint, timeout)
+	service, err := NewGRPCService(ctx, endpoint.endpoint, testProviderName, timeout)
 	if err != nil {
 		t.Fatalf("failed to create envelope service, error: %v", err)
 	}
@@ -277,7 +289,7 @@ func TestGRPCService(t *testing.T) {
 	ctx := testContext(t)
 
 	// Create the gRPC client service.
-	service, err := NewGRPCService(ctx, endpoint.endpoint, 1*time.Second)
+	service, err := NewGRPCService(ctx, endpoint.endpoint, testProviderName, 1*time.Second)
 	if err != nil {
 		t.Fatalf("failed to create envelope service, error: %v", err)
 	}
@@ -293,7 +305,7 @@ func TestGRPCService(t *testing.T) {
 
 	keyID := "1"
 	// Call service to decrypt data.
-	result, err := service.Decrypt(ctx, uid, &DecryptRequest{Ciphertext: resp.Ciphertext, KeyID: keyID})
+	result, err := service.Decrypt(ctx, uid, &kmsservice.DecryptRequest{Ciphertext: resp.Ciphertext, KeyID: keyID})
 	if err != nil {
 		t.Fatalf("failed when execute decrypt, error: %v", err)
 	}
@@ -320,7 +332,7 @@ func TestGRPCServiceConcurrentAccess(t *testing.T) {
 	ctx := testContext(t)
 
 	// Create the gRPC client service.
-	service, err := NewGRPCService(ctx, endpoint.endpoint, 15*time.Second)
+	service, err := NewGRPCService(ctx, endpoint.endpoint, testProviderName, 15*time.Second)
 	if err != nil {
 		t.Fatalf("failed to create envelope service, error: %v", err)
 	}
@@ -342,7 +354,7 @@ func TestGRPCServiceConcurrentAccess(t *testing.T) {
 
 			keyID := "1"
 			// Call service to decrypt data.
-			result, err := service.Decrypt(ctx, uid, &DecryptRequest{Ciphertext: resp.Ciphertext, KeyID: keyID})
+			result, err := service.Decrypt(ctx, uid, &kmsservice.DecryptRequest{Ciphertext: resp.Ciphertext, KeyID: keyID})
 			if err != nil {
 				t.Errorf("failed when execute decrypt, error: %v", err)
 			}
@@ -356,7 +368,7 @@ func TestGRPCServiceConcurrentAccess(t *testing.T) {
 	wg.Wait()
 }
 
-func destroyService(service Service) {
+func destroyService(service kmsservice.Service) {
 	if service != nil {
 		s := service.(*gRPCService)
 		s.connection.Close()
@@ -388,7 +400,7 @@ func TestInvalidConfiguration(t *testing.T) {
 
 	for _, testCase := range invalidConfigs {
 		t.Run(testCase.name, func(t *testing.T) {
-			_, err := NewGRPCService(ctx, testCase.endpoint, 1*time.Second)
+			_, err := NewGRPCService(ctx, testCase.endpoint, testProviderName, 1*time.Second)
 			if err == nil {
 				t.Fatalf("should fail to create envelope service for %s.", testCase.name)
 			}
@@ -396,6 +408,99 @@ func TestInvalidConfiguration(t *testing.T) {
 	}
 }
 
+func TestKMSOperationsMetric(t *testing.T) {
+	endpoint := newEndpoint()
+	f, err := mock.NewBase64Plugin(endpoint.path)
+	if err != nil {
+		t.Fatalf("failed to start test KMS provider server, error: %v", err)
+	}
+	if err := f.Start(); err != nil {
+		t.Fatalf("Failed to start kms-plugin, err: %v", err)
+	}
+
+	ctx := testContext(t)
+
+	service, err := NewGRPCService(ctx, endpoint.endpoint, testProviderName, 15*time.Second)
+	if err != nil {
+		t.Fatalf("failed to create envelope service, error: %v", err)
+	}
+	defer destroyService(service)
+	metrics.RegisterMetrics()
+
+	testCases := []struct {
+		name        string
+		operation   func()
+		labelValues []string
+		wantCount   uint64
+	}{
+		{
+			name: "encrypt",
+			operation: func() {
+				if _, err = service.Encrypt(ctx, "1", []byte("test data")); err != nil {
+					t.Fatalf("failed when execute encrypt, error: %v", err)
+				}
+			},
+			labelValues: []string{testProviderName, "/v2.KeyManagementService/Encrypt", "OK"},
+			wantCount:   1,
+		},
+		{
+			name: "decrypt",
+			operation: func() {
+				if _, err = service.Decrypt(ctx, "1", &kmsservice.DecryptRequest{Ciphertext: []byte("testdata"), KeyID: "1"}); err != nil {
+					t.Fatalf("failed when execute decrypt, error: %v", err)
+				}
+			},
+			labelValues: []string{testProviderName, "/v2.KeyManagementService/Decrypt", "OK"},
+			wantCount:   1,
+		},
+		{
+			name: "status",
+			operation: func() {
+				if _, err = service.Status(ctx); err != nil {
+					t.Fatalf("failed when execute status, error: %v", err)
+				}
+			},
+			labelValues: []string{testProviderName, "/v2.KeyManagementService/Status", "OK"},
+			wantCount:   1,
+		},
+		{
+			name: "multiple status calls",
+			operation: func() {
+				for i := 0; i < 10; i++ {
+					if _, err = service.Status(ctx); err != nil {
+						t.Fatalf("failed when execute status, error: %v", err)
+					}
+				}
+			},
+			labelValues: []string{testProviderName, "/v2.KeyManagementService/Status", "OK"},
+			wantCount:   10,
+		},
+	}
+
+	for _, tt := range testCases {
+		t.Run(tt.name, func(t *testing.T) {
+			tt.operation()
+			defer metrics.KMSOperationsLatencyMetric.Reset()
+			sampleSum, err := testutil.GetHistogramMetricValue(metrics.KMSOperationsLatencyMetric.WithLabelValues(tt.labelValues...))
+			if err != nil {
+				t.Fatalf("failed to get metric value, error: %v", err)
+			}
+			// apiserver_envelope_encryption_kms_operations_latency_seconds_sum{grpc_status_code="OK",method_name="/v2alpha1.KeyManagementService/Encrypt",provider_name="providerName"} 0.000881432
+			if sampleSum == 0 {
+				t.Fatalf("expected metric value to be greater than 0, got %v", sampleSum)
+			}
+			count, err := testutil.GetHistogramMetricCount(metrics.KMSOperationsLatencyMetric.WithLabelValues(tt.labelValues...))
+			if err != nil {
+				t.Fatalf("failed to get metric count, error: %v", err)
+			}
+			// apiserver_envelope_encryption_kms_operations_latency_seconds_count{grpc_status_code="OK",method_name="/v2alpha1.KeyManagementService/Encrypt",provider_name="providerName"} 1
+			if count != tt.wantCount {
+				t.Fatalf("expected metric count to be %v, got %v", tt.wantCount, count)
+			}
+		})
+	}
+}
+
 func testContext(t *testing.T) context.Context {
 	ctx, cancel := context.WithCancel(context.Background())
 	t.Cleanup(cancel)
