@@ -49,10 +49,10 @@ var _ = SIGDescribe("[Feature:NodeAuthorizer]", func() {
 	var ns string
 	var asUser string
 	var nodeName string
-	ginkgo.BeforeEach(func() {
+	ginkgo.BeforeEach(func(ctx context.Context) {
 		ns = f.Namespace.Name
 
-		nodeList, err := f.ClientSet.CoreV1().Nodes().List(context.TODO(), metav1.ListOptions{})
+		nodeList, err := f.ClientSet.CoreV1().Nodes().List(ctx, metav1.ListOptions{})
 		framework.ExpectNoError(err, "failed to list nodes in namespace: %s", ns)
 		framework.ExpectNotEqual(len(nodeList.Items), 0)
 		nodeName = nodeList.Items[0].Name
@@ -68,14 +68,14 @@ var _ = SIGDescribe("[Feature:NodeAuthorizer]", func() {
 		framework.ExpectNoError(err, "failed to create Clientset for the given config: %+v", *config)
 
 	})
-	ginkgo.It("Getting a non-existent secret should exit with the Forbidden error, not a NotFound error", func() {
-		_, err := c.CoreV1().Secrets(ns).Get(context.TODO(), "foo", metav1.GetOptions{})
+	ginkgo.It("Getting a non-existent secret should exit with the Forbidden error, not a NotFound error", func(ctx context.Context) {
+		_, err := c.CoreV1().Secrets(ns).Get(ctx, "foo", metav1.GetOptions{})
 		if !apierrors.IsForbidden(err) {
 			framework.Failf("should be a forbidden error, got %#v", err)
 		}
 	})
 
-	ginkgo.It("Getting an existing secret should exit with the Forbidden error", func() {
+	ginkgo.It("Getting an existing secret should exit with the Forbidden error", func(ctx context.Context) {
 		ginkgo.By("Create a secret for testing")
 		secret := &v1.Secret{
 			ObjectMeta: metav1.ObjectMeta{
@@ -84,22 +84,22 @@ var _ = SIGDescribe("[Feature:NodeAuthorizer]", func() {
 			},
 			StringData: map[string]string{},
 		}
-		_, err := f.ClientSet.CoreV1().Secrets(ns).Create(context.TODO(), secret, metav1.CreateOptions{})
+		_, err := f.ClientSet.CoreV1().Secrets(ns).Create(ctx, secret, metav1.CreateOptions{})
 		framework.ExpectNoError(err, "failed to create secret (%s:%s) %+v", ns, secret.Name, *secret)
-		_, err = c.CoreV1().Secrets(ns).Get(context.TODO(), secret.Name, metav1.GetOptions{})
+		_, err = c.CoreV1().Secrets(ns).Get(ctx, secret.Name, metav1.GetOptions{})
 		if !apierrors.IsForbidden(err) {
 			framework.Failf("should be a forbidden error, got %#v", err)
 		}
 	})
 
-	ginkgo.It("Getting a non-existent configmap should exit with the Forbidden error, not a NotFound error", func() {
-		_, err := c.CoreV1().ConfigMaps(ns).Get(context.TODO(), "foo", metav1.GetOptions{})
+	ginkgo.It("Getting a non-existent configmap should exit with the Forbidden error, not a NotFound error", func(ctx context.Context) {
+		_, err := c.CoreV1().ConfigMaps(ns).Get(ctx, "foo", metav1.GetOptions{})
 		if !apierrors.IsForbidden(err) {
 			framework.Failf("should be a forbidden error, got %#v", err)
 		}
 	})
 
-	ginkgo.It("Getting an existing configmap should exit with the Forbidden error", func() {
+	ginkgo.It("Getting an existing configmap should exit with the Forbidden error", func(ctx context.Context) {
 		ginkgo.By("Create a configmap for testing")
 		configmap := &v1.ConfigMap{
 			ObjectMeta: metav1.ObjectMeta{
@@ -110,15 +110,15 @@ var _ = SIGDescribe("[Feature:NodeAuthorizer]", func() {
 				"data": "content",
 			},
 		}
-		_, err := f.ClientSet.CoreV1().ConfigMaps(ns).Create(context.TODO(), configmap, metav1.CreateOptions{})
+		_, err := f.ClientSet.CoreV1().ConfigMaps(ns).Create(ctx, configmap, metav1.CreateOptions{})
 		framework.ExpectNoError(err, "failed to create configmap (%s:%s) %+v", ns, configmap.Name, *configmap)
-		_, err = c.CoreV1().ConfigMaps(ns).Get(context.TODO(), configmap.Name, metav1.GetOptions{})
+		_, err = c.CoreV1().ConfigMaps(ns).Get(ctx, configmap.Name, metav1.GetOptions{})
 		if !apierrors.IsForbidden(err) {
 			framework.Failf("should be a forbidden error, got %#v", err)
 		}
 	})
 
-	ginkgo.It("Getting a secret for a workload the node has access to should succeed", func() {
+	ginkgo.It("Getting a secret for a workload the node has access to should succeed", func(ctx context.Context) {
 		ginkgo.By("Create a secret for testing")
 		secret := &v1.Secret{
 			ObjectMeta: metav1.ObjectMeta{
@@ -129,11 +129,11 @@ var _ = SIGDescribe("[Feature:NodeAuthorizer]", func() {
 				"data": []byte("keep it secret"),
 			},
 		}
-		_, err := f.ClientSet.CoreV1().Secrets(ns).Create(context.TODO(), secret, metav1.CreateOptions{})
+		_, err := f.ClientSet.CoreV1().Secrets(ns).Create(ctx, secret, metav1.CreateOptions{})
 		framework.ExpectNoError(err, "failed to create secret (%s:%s)", ns, secret.Name)
 
 		ginkgo.By("Node should not get the secret")
-		_, err = c.CoreV1().Secrets(ns).Get(context.TODO(), secret.Name, metav1.GetOptions{})
+		_, err = c.CoreV1().Secrets(ns).Get(ctx, secret.Name, metav1.GetOptions{})
 		if !apierrors.IsForbidden(err) {
 			framework.Failf("should be a forbidden error, got %#v", err)
 		}
@@ -164,14 +164,14 @@ var _ = SIGDescribe("[Feature:NodeAuthorizer]", func() {
 			},
 		}
 
-		_, err = f.ClientSet.CoreV1().Pods(ns).Create(context.TODO(), pod, metav1.CreateOptions{})
+		_, err = f.ClientSet.CoreV1().Pods(ns).Create(ctx, pod, metav1.CreateOptions{})
 		framework.ExpectNoError(err, "failed to create pod (%s:%s)", ns, pod.Name)
 
 		ginkgo.By("The node should able to access the secret")
 		itv := framework.Poll
 		dur := 1 * time.Minute
 		err = wait.Poll(itv, dur, func() (bool, error) {
-			_, err = c.CoreV1().Secrets(ns).Get(context.TODO(), secret.Name, metav1.GetOptions{})
+			_, err = c.CoreV1().Secrets(ns).Get(ctx, secret.Name, metav1.GetOptions{})
 			if err != nil {
 				framework.Logf("Failed to get secret %v, err: %v", secret.Name, err)
 				return false, nil
@@ -181,7 +181,7 @@ var _ = SIGDescribe("[Feature:NodeAuthorizer]", func() {
 		framework.ExpectNoError(err, "failed to get secret after trying every %v for %v (%s:%s)", itv, dur, ns, secret.Name)
 	})
 
-	ginkgo.It("A node shouldn't be able to create another node", func() {
+	ginkgo.It("A node shouldn't be able to create another node", func(ctx context.Context) {
 		node := &v1.Node{
 			ObjectMeta: metav1.ObjectMeta{Name: "foo"},
 			TypeMeta: metav1.TypeMeta{
@@ -190,22 +190,21 @@ var _ = SIGDescribe("[Feature:NodeAuthorizer]", func() {
 			},
 		}
 		ginkgo.By(fmt.Sprintf("Create node foo by user: %v", asUser))
-		_, err := c.CoreV1().Nodes().Create(context.TODO(), node, metav1.CreateOptions{})
+		_, err := c.CoreV1().Nodes().Create(ctx, node, metav1.CreateOptions{})
 
 		// NOTE: If the test fails and a new node IS created, we need to delete it. If we don't, we'd have
 		// a zombie node in a NotReady state which will delay further tests since we're waiting for all
 		// tests to be in the Ready state.
-		defer func() {
-			f.ClientSet.CoreV1().Nodes().Delete(context.TODO(), node.Name, metav1.DeleteOptions{})
-		}()
+		ginkgo.DeferCleanup(framework.IgnoreNotFound(f.ClientSet.CoreV1().Nodes().Delete), node.Name, metav1.DeleteOptions{})
+
 		if !apierrors.IsForbidden(err) {
 			framework.Failf("should be a forbidden error, got %#v", err)
 		}
 	})
 
-	ginkgo.It("A node shouldn't be able to delete another node", func() {
+	ginkgo.It("A node shouldn't be able to delete another node", func(ctx context.Context) {
 		ginkgo.By(fmt.Sprintf("Create node foo by user: %v", asUser))
-		err := c.CoreV1().Nodes().Delete(context.TODO(), "foo", metav1.DeleteOptions{})
+		err := c.CoreV1().Nodes().Delete(ctx, "foo", metav1.DeleteOptions{})
 		if !apierrors.IsForbidden(err) {
 			framework.Failf("should be a forbidden error, got %#v", err)
 		}
